import 'currency.dart';

const currencies = {
  "aed": Currency(
    isoCode: "AED",
    name: "United Arab Emirates Dirham",
    symbol: "د.إ",
    alternateSymbols: ["DH", "Dhs"],
    subunit: "Fils",
    subunitToUnit: 100,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 784,
    smallestDenomination: 25,
  ),
  "afn": Currency(
    isoCode: "AFN",
    name: "Afghan Afghani",
    symbol: "؋",
    alternateSymbols: ["Af", "Afs"],
    subunit: "Pul",
    subunitToUnit: 100,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 971,
    smallestDenomination: 100,
  ),
  "all": Currency(
    isoCode: "ALL",
    name: "Albanian Lek",
    symbol: "L",
    disambiguateSymbol: "Lek",
    alternateSymbols: ["Lek"],
    subunit: "Qintar",
    subunitToUnit: 100,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 008,
    smallestDenomination: 100,
  ),
  "amd": Currency(
    isoCode: "AMD",
    name: "Armenian Dram",
    symbol: "դր.",
    alternateSymbols: ["dram"],
    subunit: "Luma",
    subunitToUnit: 100,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 051,
    smallestDenomination: 10,
  ),
  "ang": Currency(
    isoCode: "ANG",
    name: "Netherlands Antillean Gulden",
    symbol: "ƒ",
    alternateSymbols: ["NAƒ", "NAf", "f"],
    subunit: "Cent",
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ",",
    thousandsSeparator: ".",
    isoNumeric: 532,
    smallestDenomination: 1,
  ),
  "aoa": Currency(
    isoCode: "AOA",
    name: "Angolan Kwanza",
    symbol: "Kz",
    alternateSymbols: [],
    subunit: "Cêntimo",
    subunitToUnit: 100,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 973,
    smallestDenomination: 10,
  ),
  "ars": Currency(
    isoCode: "ARS",
    name: "Argentine Peso",
    symbol: "\$",
    disambiguateSymbol: "\$m/n",
    alternateSymbols: ["\$m/n", "m\$n"],
    subunit: "Centavo",
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ",",
    thousandsSeparator: ".",
    isoNumeric: 032,
    smallestDenomination: 1,
  ),
  "aud": Currency(
    isoCode: "AUD",
    name: "Australian Dollar",
    symbol: "\$",
    disambiguateSymbol: "A\$",
    alternateSymbols: ["A\$"],
    subunit: "Cent",
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 036,
    smallestDenomination: 5,
  ),
  "awg": Currency(
    isoCode: "AWG",
    name: "Aruban Florin",
    symbol: "ƒ",
    alternateSymbols: ["Afl"],
    subunit: "Cent",
    subunitToUnit: 100,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 533,
    smallestDenomination: 5,
  ),
  "azn": Currency(
    isoCode: "AZN",
    name: "Azerbaijani Manat",
    symbol: "₼",
    alternateSymbols: ["m", "man"],
    subunit: "Qəpik",
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 944,
    smallestDenomination: 1,
  ),
  "bam": Currency(
    isoCode: "BAM",
    name: "Bosnia and Herzegovina Convertible Mark",
    symbol: "КМ",
    alternateSymbols: ["KM"],
    subunit: "Fening",
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 977,
    smallestDenomination: 5,
  ),
  "bbd": Currency(
    isoCode: "BBD",
    name: "Barbadian Dollar",
    symbol: "\$",
    disambiguateSymbol: "Bds\$",
    alternateSymbols: ["Bds\$"],
    subunit: "Cent",
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 052,
    smallestDenomination: 1,
  ),
  "bdt": Currency(
    isoCode: "BDT",
    name: "Bangladeshi Taka",
    symbol: "৳",
    alternateSymbols: ["Tk"],
    subunit: "Paisa",
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 050,
    smallestDenomination: 1,
  ),
  "bgn": Currency(
    isoCode: "BGN",
    name: "Bulgarian Lev",
    symbol: "лв.",
    alternateSymbols: ["lev", "leva", "лев", "лева"],
    subunit: "Stotinka",
    subunitToUnit: 100,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 975,
    smallestDenomination: 1,
  ),
  "bhd": Currency(
    isoCode: "BHD",
    name: "Bahraini Dinar",
    symbol: "د.ب",
    alternateSymbols: ["BD"],
    subunit: "Fils",
    subunitToUnit: 1000,
    symbolFirst: true,
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 048,
    smallestDenomination: 5,
  ),
  "bif": Currency(
    isoCode: "BIF",
    name: "Burundian Franc",
    symbol: "Fr",
    disambiguateSymbol: "FBu",
    alternateSymbols: ["FBu"],
    subunit: "Centime",
    subunitToUnit: 1,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 108,
    smallestDenomination: 100,
  ),
  "bmd": Currency(
    isoCode: "BMD",
    name: "Bermudian Dollar",
    symbol: "\$",
    disambiguateSymbol: "BD\$",
    alternateSymbols: ["BD\$"],
    subunit: "Cent",
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 060,
    smallestDenomination: 1,
  ),
  "bnd": Currency(
    isoCode: "BND",
    name: "Brunei Dollar",
    symbol: "\$",
    disambiguateSymbol: "BND",
    alternateSymbols: ["B\$"],
    subunit: "Sen",
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 096,
    smallestDenomination: 1,
  ),
  "bob": Currency(
    isoCode: "BOB",
    name: "Bolivian Boliviano",
    symbol: "Bs.",
    alternateSymbols: ["Bs"],
    subunit: "Centavo",
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 068,
    smallestDenomination: 10,
  ),
  "brl": Currency(
    isoCode: "BRL",
    name: "Brazilian Real",
    symbol: "R\$",
    subunit: "Centavo",
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ",",
    thousandsSeparator: ".",
    isoNumeric: 986,
    smallestDenomination: 5,
  ),
  "bsd": Currency(
    isoCode: "BSD",
    name: "Bahamian Dollar",
    symbol: "\$",
    disambiguateSymbol: "BSD",
    alternateSymbols: ["B\$"],
    subunit: "Cent",
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 044,
    smallestDenomination: 1,
  ),
  "btn": Currency(
    isoCode: "BTN",
    name: "Bhutanese Ngultrum",
    symbol: "Nu.",
    alternateSymbols: ["Nu"],
    subunit: "Chertrum",
    subunitToUnit: 100,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 064,
    smallestDenomination: 5,
  ),
  "bwp": Currency(
    isoCode: "BWP",
    name: "Botswana Pula",
    symbol: "P",
    alternateSymbols: [],
    subunit: "Thebe",
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 072,
    smallestDenomination: 5,
  ),
  "byn": Currency(
    isoCode: "BYN",
    name: "Belarusian Ruble",
    symbol: "Br",
    disambiguateSymbol: "BYN",
    alternateSymbols: ["бел. руб.", "б.р.", "руб.", "р."],
    subunit: "Kapeyka",
    subunitToUnit: 100,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ",",
    thousandsSeparator: " ",
    isoNumeric: 933,
    smallestDenomination: 1,
  ),
  "byr": Currency(
    isoCode: "BYR",
    name: "Belarusian Ruble",
    symbol: "Br",
    disambiguateSymbol: "BYR",
    alternateSymbols: ["бел. руб.", "б.р.", "руб.", "р."],
    subunit: null,
    subunitToUnit: 1,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ",",
    thousandsSeparator: " ",
    isoNumeric: 974,
    smallestDenomination: 100,
  ),
  "bzd": Currency(
    isoCode: "BZD",
    name: "Belize Dollar",
    symbol: "\$",
    disambiguateSymbol: "BZ\$",
    alternateSymbols: ["BZ\$"],
    subunit: "Cent",
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 084,
    smallestDenomination: 1,
  ),
  "cad": Currency(
    isoCode: "CAD",
    name: "Canadian Dollar",
    symbol: "\$",
    disambiguateSymbol: "C\$",
    alternateSymbols: ["C\$", "CAD\$"],
    subunit: "Cent",
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 124,
    smallestDenomination: 5,
  ),
  "cdf": Currency(
    isoCode: "CDF",
    name: "Congolese Franc",
    symbol: "Fr",
    disambiguateSymbol: "FC",
    alternateSymbols: ["FC"],
    subunit: "Centime",
    subunitToUnit: 100,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 976,
    smallestDenomination: 1,
  ),
  "chf": Currency(
    isoCode: "CHF",
    name: "Swiss Franc",
    symbol: "CHF",
    alternateSymbols: ["SFr", "Fr"],
    subunit: "Rappen",
    subunitToUnit: 100,
    symbolFirst: true,
    format: "%u%n",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 756,
    smallestDenomination: 5,
  ),
  "clf": Currency(
    isoCode: "CLF",
    name: "Unidad de Fomento",
    symbol: "UF",
    alternateSymbols: [],
    subunit: "Peso",
    subunitToUnit: 10000,
    symbolFirst: true,
    decimalMark: ",",
    thousandsSeparator: ".",
    isoNumeric: 990,
  ),
  "clp": Currency(
    isoCode: "CLP",
    name: "Chilean Peso",
    symbol: "\$",
    disambiguateSymbol: "CLP",
    alternateSymbols: [],
    subunit: "Peso",
    subunitToUnit: 1,
    symbolFirst: true,
    decimalMark: ",",
    thousandsSeparator: ".",
    isoNumeric: 152,
    smallestDenomination: 1,
  ),
  "cny": Currency(
    isoCode: "CNY",
    name: "Chinese Renminbi Yuan",
    symbol: "¥",
    alternateSymbols: ["CN¥", "元", "CN元"],
    subunit: "Fen",
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 156,
    smallestDenomination: 1,
  ),
  "cop": Currency(
    isoCode: "COP",
    name: "Colombian Peso",
    symbol: "\$",
    disambiguateSymbol: "COL\$",
    alternateSymbols: ["COL\$"],
    subunit: "Centavo",
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ",",
    thousandsSeparator: ".",
    isoNumeric: 170,
    smallestDenomination: 20,
  ),
  "crc": Currency(
    isoCode: "CRC",
    name: "Costa Rican Colón",
    symbol: "₡",
    alternateSymbols: ["¢"],
    subunit: "Céntimo",
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ",",
    thousandsSeparator: ".",
    isoNumeric: 188,
    smallestDenomination: 500,
  ),
  "cuc": Currency(
    isoCode: "CUC",
    name: "Cuban Convertible Peso",
    symbol: "\$",
    disambiguateSymbol: "CUC\$",
    alternateSymbols: ["CUC\$"],
    subunit: "Centavo",
    subunitToUnit: 100,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 931,
    smallestDenomination: 1,
  ),
  "cup": Currency(
    isoCode: "CUP",
    name: "Cuban Peso",
    symbol: "\$",
    disambiguateSymbol: "\$MN",
    alternateSymbols: ["\$MN"],
    subunit: "Centavo",
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 192,
    smallestDenomination: 1,
  ),
  "cve": Currency(
    isoCode: "CVE",
    name: "Cape Verdean Escudo",
    symbol: "\$",
    disambiguateSymbol: "Esc",
    alternateSymbols: ["Esc"],
    subunit: "Centavo",
    subunitToUnit: 100,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 132,
    smallestDenomination: 100,
  ),
  "czk": Currency(
    isoCode: "CZK",
    name: "Czech Koruna",
    symbol: "Kč",
    alternateSymbols: [],
    subunit: "Haléř",
    subunitToUnit: 100,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ",",
    thousandsSeparator: " ",
    isoNumeric: 203,
    smallestDenomination: 100,
  ),
  "djf": Currency(
    isoCode: "DJF",
    name: "Djiboutian Franc",
    symbol: "Fdj",
    alternateSymbols: [],
    subunit: "Centime",
    subunitToUnit: 1,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 262,
    smallestDenomination: 100,
  ),
  "dkk": Currency(
    isoCode: "DKK",
    name: "Danish Krone",
    symbol: "kr.",
    disambiguateSymbol: "DKK",
    alternateSymbols: [",-"],
    subunit: "Øre",
    subunitToUnit: 100,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ",",
    thousandsSeparator: ".",
    isoNumeric: 208,
    smallestDenomination: 50,
  ),
  "dop": Currency(
    isoCode: "DOP",
    name: "Dominican Peso",
    symbol: "\$",
    disambiguateSymbol: "RD\$",
    alternateSymbols: ["RD\$"],
    subunit: "Centavo",
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 214,
    smallestDenomination: 100,
  ),
  "dzd": Currency(
    isoCode: "DZD",
    name: "Algerian Dinar",
    symbol: "د.ج",
    alternateSymbols: ["DA"],
    subunit: "Centime",
    subunitToUnit: 100,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 012,
    smallestDenomination: 100,
  ),
  "egp": Currency(
    isoCode: "EGP",
    name: "Egyptian Pound",
    symbol: "ج.م",
    alternateSymbols: ["LE", "E£", "L.E."],
    subunit: "Piastre",
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 818,
    smallestDenomination: 25,
  ),
  "ern": Currency(
    isoCode: "ERN",
    name: "Eritrean Nakfa",
    symbol: "Nfk",
    alternateSymbols: [],
    subunit: "Cent",
    subunitToUnit: 100,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 232,
    smallestDenomination: 1,
  ),
  "etb": Currency(
    isoCode: "ETB",
    name: "Ethiopian Birr",
    symbol: "Br",
    disambiguateSymbol: "ETB",
    alternateSymbols: [],
    subunit: "Santim",
    subunitToUnit: 100,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 230,
    smallestDenomination: 1,
  ),
  "eur": Currency(
    isoCode: "EUR",
    name: "Euro",
    symbol: "€",
    alternateSymbols: [],
    subunit: "Cent",
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ",",
    thousandsSeparator: ".",
    isoNumeric: 978,
    smallestDenomination: 1,
  ),
  "fjd": Currency(
    isoCode: "FJD",
    name: "Fijian Dollar",
    symbol: "\$",
    disambiguateSymbol: "FJ\$",
    alternateSymbols: ["FJ\$"],
    subunit: "Cent",
    subunitToUnit: 100,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 242,
    smallestDenomination: 5,
  ),
  "fkp": Currency(
    isoCode: "FKP",
    name: "Falkland Pound",
    symbol: "£",
    disambiguateSymbol: "FK£",
    alternateSymbols: ["FK£"],
    subunit: "Penny",
    subunitToUnit: 100,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 238,
    smallestDenomination: 1,
  ),
  "gbp": Currency(
    isoCode: "GBP",
    name: "British Pound",
    symbol: "£",
    alternateSymbols: [],
    subunit: "Penny",
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 826,
    smallestDenomination: 1,
  ),
  "gel": Currency(
    isoCode: "GEL",
    name: "Georgian Lari",
    symbol: "ლ",
    alternateSymbols: ["lari"],
    subunit: "Tetri",
    subunitToUnit: 100,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 981,
    smallestDenomination: 1,
  ),
  "ghs": Currency(
    isoCode: "GHS",
    name: "Ghanaian Cedi",
    symbol: "₵",
    alternateSymbols: ["GH¢", "GH₵"],
    subunit: "Pesewa",
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 936,
    smallestDenomination: 1,
  ),
  "gip": Currency(
    isoCode: "GIP",
    name: "Gibraltar Pound",
    symbol: "£",
    disambiguateSymbol: "GIP",
    alternateSymbols: [],
    subunit: "Penny",
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 292,
    smallestDenomination: 1,
  ),
  "gmd": Currency(
    isoCode: "GMD",
    name: "Gambian Dalasi",
    symbol: "D",
    alternateSymbols: [],
    subunit: "Butut",
    subunitToUnit: 100,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 270,
    smallestDenomination: 1,
  ),
  "gnf": Currency(
    isoCode: "GNF",
    name: "Guinean Franc",
    symbol: "Fr",
    disambiguateSymbol: "FG",
    alternateSymbols: ["FG", "GFr"],
    subunit: "Centime",
    subunitToUnit: 1,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 324,
    smallestDenomination: 100,
  ),
  "gtq": Currency(
    isoCode: "GTQ",
    name: "Guatemalan Quetzal",
    symbol: "Q",
    alternateSymbols: [],
    subunit: "Centavo",
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 320,
    smallestDenomination: 1,
  ),
  "gyd": Currency(
    isoCode: "GYD",
    name: "Guyanese Dollar",
    symbol: "\$",
    disambiguateSymbol: "G\$",
    alternateSymbols: ["G\$"],
    subunit: "Cent",
    subunitToUnit: 100,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 328,
    smallestDenomination: 100,
  ),
  "hkd": Currency(
    isoCode: "HKD",
    name: "Hong Kong Dollar",
    symbol: "\$",
    disambiguateSymbol: "HK\$",
    alternateSymbols: ["HK\$"],
    subunit: "Cent",
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 344,
    smallestDenomination: 10,
  ),
  "hnl": Currency(
    isoCode: "HNL",
    name: "Honduran Lempira",
    symbol: "L",
    disambiguateSymbol: "HNL",
    alternateSymbols: [],
    subunit: "Centavo",
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 340,
    smallestDenomination: 5,
  ),
  "hrk": Currency(
    isoCode: "HRK",
    name: "Croatian Kuna",
    symbol: "kn",
    alternateSymbols: [],
    subunit: "Lipa",
    subunitToUnit: 100,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ",",
    thousandsSeparator: ".",
    isoNumeric: 191,
    smallestDenomination: 1,
  ),
  "htg": Currency(
    isoCode: "HTG",
    name: "Haitian Gourde",
    symbol: "G",
    alternateSymbols: [],
    subunit: "Centime",
    subunitToUnit: 100,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 332,
    smallestDenomination: 5,
  ),
  "huf": Currency(
    isoCode: "HUF",
    name: "Hungarian Forint",
    symbol: "Ft",
    alternateSymbols: [],
    subunit: "",
    subunitToUnit: 1,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ",",
    thousandsSeparator: " ",
    isoNumeric: 348,
    smallestDenomination: 5,
  ),
  "idr": Currency(
    isoCode: "IDR",
    name: "Indonesian Rupiah",
    symbol: "Rp",
    alternateSymbols: [],
    subunit: "Sen",
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ",",
    thousandsSeparator: ".",
    isoNumeric: 360,
    smallestDenomination: 5000,
  ),
  "ils": Currency(
    isoCode: "ILS",
    name: "Israeli New Sheqel",
    symbol: "₪",
    alternateSymbols: ["ש״ח", "NIS"],
    subunit: "Agora",
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 376,
    smallestDenomination: 10,
  ),
  "inr": Currency(
    isoCode: "INR",
    name: "Indian Rupee",
    symbol: "₹",
    alternateSymbols: ["Rs", "৳", "૱", "௹", "रु", "₨"],
    subunit: "Paisa",
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 356,
    smallestDenomination: 50,
  ),
  "iqd": Currency(
    isoCode: "IQD",
    name: "Iraqi Dinar",
    symbol: "ع.د",
    alternateSymbols: [],
    subunit: "Fils",
    subunitToUnit: 1000,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 368,
    smallestDenomination: 50000,
  ),
  "irr": Currency(
    isoCode: "IRR",
    name: "Iranian Rial",
    symbol: "﷼",
    alternateSymbols: [],
    subunit: null,
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 364,
    smallestDenomination: 5000,
  ),
  "isk": Currency(
    isoCode: "ISK",
    name: "Icelandic Króna",
    symbol: "kr.",
    alternateSymbols: ["Íkr"],
    subunit: null,
    subunitToUnit: 1,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ",",
    thousandsSeparator: ".",
    isoNumeric: 352,
    smallestDenomination: 1,
  ),
  "jmd": Currency(
    isoCode: "JMD",
    name: "Jamaican Dollar",
    symbol: "\$",
    disambiguateSymbol: "J\$",
    alternateSymbols: ["J\$"],
    subunit: "Cent",
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 388,
    smallestDenomination: 1,
  ),
  "jod": Currency(
    isoCode: "JOD",
    name: "Jordanian Dinar",
    symbol: "د.ا",
    alternateSymbols: ["JD"],
    subunit: "Fils",
    subunitToUnit: 1000,
    symbolFirst: true,
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 400,
    smallestDenomination: 5,
  ),
  "jpy": Currency(
    isoCode: "JPY",
    name: "Japanese Yen",
    symbol: "¥",
    alternateSymbols: ["円", "圓"],
    subunit: null,
    subunitToUnit: 1,
    symbolFirst: true,
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 392,
    smallestDenomination: 1,
  ),
  "kes": Currency(
    isoCode: "KES",
    name: "Kenyan Shilling",
    symbol: "KSh",
    alternateSymbols: ["Sh"],
    subunit: "Cent",
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 404,
    smallestDenomination: 50,
  ),
  "kgs": Currency(
    isoCode: "KGS",
    name: "Kyrgyzstani Som",
    symbol: "som",
    alternateSymbols: ["сом"],
    subunit: "Tyiyn",
    subunitToUnit: 100,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 417,
    smallestDenomination: 1,
  ),
  "khr": Currency(
    isoCode: "KHR",
    name: "Cambodian Riel",
    symbol: "៛",
    alternateSymbols: [],
    subunit: "Sen",
    subunitToUnit: 100,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 116,
    smallestDenomination: 5000,
  ),
  "kmf": Currency(
    isoCode: "KMF",
    name: "Comorian Franc",
    symbol: "Fr",
    disambiguateSymbol: "CF",
    alternateSymbols: ["CF"],
    subunit: "Centime",
    subunitToUnit: 1,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 174,
    smallestDenomination: 100,
  ),
  "kpw": Currency(
    isoCode: "KPW",
    name: "North Korean Won",
    symbol: "₩",
    alternateSymbols: [],
    subunit: "Chŏn",
    subunitToUnit: 100,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 408,
    smallestDenomination: 1,
  ),
  "krw": Currency(
    isoCode: "KRW",
    name: "South Korean Won",
    symbol: "₩",
    subunit: null,
    subunitToUnit: 1,
    alternateSymbols: [],
    symbolFirst: true,
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 410,
    smallestDenomination: 1,
  ),
  "kwd": Currency(
    isoCode: "KWD",
    name: "Kuwaiti Dinar",
    symbol: "د.ك",
    alternateSymbols: ["K.D."],
    subunit: "Fils",
    subunitToUnit: 1000,
    symbolFirst: true,
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 414,
    smallestDenomination: 5,
  ),
  "kyd": Currency(
    isoCode: "KYD",
    name: "Cayman Islands Dollar",
    symbol: "\$",
    disambiguateSymbol: "CI\$",
    alternateSymbols: ["CI\$"],
    subunit: "Cent",
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 136,
    smallestDenomination: 1,
  ),
  "kzt": Currency(
    isoCode: "KZT",
    name: "Kazakhstani Tenge",
    symbol: "₸",
    alternateSymbols: [],
    subunit: "Tiyn",
    subunitToUnit: 100,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 398,
    smallestDenomination: 100,
  ),
  "lak": Currency(
    isoCode: "LAK",
    name: "Lao Kip",
    symbol: "₭",
    alternateSymbols: ["₭N"],
    subunit: "Att",
    subunitToUnit: 100,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 418,
    smallestDenomination: 10,
  ),
  "lbp": Currency(
    isoCode: "LBP",
    name: "Lebanese Pound",
    symbol: "ل.ل",
    alternateSymbols: ["£", "L£"],
    subunit: "Piastre",
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 422,
    smallestDenomination: 25000,
  ),
  "lkr": Currency(
    isoCode: "LKR",
    name: "Sri Lankan Rupee",
    symbol: "₨",
    disambiguateSymbol: "SLRs",
    alternateSymbols: ["රු", "ரூ", "SLRs", "/-"],
    subunit: "Cent",
    subunitToUnit: 100,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 144,
    smallestDenomination: 100,
  ),
  "lrd": Currency(
    isoCode: "LRD",
    name: "Liberian Dollar",
    symbol: "\$",
    disambiguateSymbol: "L\$",
    alternateSymbols: ["L\$"],
    subunit: "Cent",
    subunitToUnit: 100,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 430,
    smallestDenomination: 5,
  ),
  "lsl": Currency(
    isoCode: "LSL",
    name: "Lesotho Loti",
    symbol: "L",
    disambiguateSymbol: "M",
    alternateSymbols: ["M"],
    subunit: "Sente",
    subunitToUnit: 100,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 426,
    smallestDenomination: 1,
  ),
  "lyd": Currency(
    isoCode: "LYD",
    name: "Libyan Dinar",
    symbol: "ل.د",
    alternateSymbols: ["LD"],
    subunit: "Dirham",
    subunitToUnit: 1000,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 434,
    smallestDenomination: 50,
  ),
  "mad": Currency(
    isoCode: "MAD",
    name: "Moroccan Dirham",
    symbol: "د.م.",
    alternateSymbols: [],
    subunit: "Centime",
    subunitToUnit: 100,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 504,
    smallestDenomination: 1,
  ),
  "mdl": Currency(
    isoCode: "MDL",
    name: "Moldovan Leu",
    symbol: "L",
    alternateSymbols: ["lei"],
    subunit: "Ban",
    subunitToUnit: 100,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 498,
    smallestDenomination: 1,
  ),
  "mga": Currency(
    isoCode: "MGA",
    name: "Malagasy Ariary",
    symbol: "Ar",
    alternateSymbols: [],
    subunit: "Iraimbilanja",
    subunitToUnit: 5,
    symbolFirst: true,
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 969,
    smallestDenomination: 1,
  ),
  "mkd": Currency(
    isoCode: "MKD",
    name: "Macedonian Denar",
    symbol: "ден",
    alternateSymbols: [],
    subunit: "Deni",
    subunitToUnit: 100,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 807,
    smallestDenomination: 100,
  ),
  "mmk": Currency(
    isoCode: "MMK",
    name: "Myanmar Kyat",
    symbol: "K",
    disambiguateSymbol: "MMK",
    alternateSymbols: [],
    subunit: "Pya",
    subunitToUnit: 100,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 104,
    smallestDenomination: 50,
  ),
  "mnt": Currency(
    isoCode: "MNT",
    name: "Mongolian Tögrög",
    symbol: "₮",
    alternateSymbols: [],
    subunit: "Möngö",
    subunitToUnit: 100,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 496,
    smallestDenomination: 2000,
  ),
  "mop": Currency(
    isoCode: "MOP",
    name: "Macanese Pataca",
    symbol: "P",
    alternateSymbols: ["MOP\$"],
    subunit: "Avo",
    subunitToUnit: 100,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 446,
    smallestDenomination: 10,
  ),
  "mru": Currency(
    isoCode: "MRU",
    name: "Mauritanian Ouguiya",
    symbol: "UM",
    alternateSymbols: [],
    subunit: "Khoums",
    subunitToUnit: 5,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 929,
    smallestDenomination: 1,
  ),
  "mur": Currency(
    isoCode: "MUR",
    name: "Mauritian Rupee",
    symbol: "₨",
    alternateSymbols: [],
    subunit: "Cent",
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 480,
    smallestDenomination: 100,
  ),
  "mvr": Currency(
    isoCode: "MVR",
    name: "Maldivian Rufiyaa",
    symbol: "MVR",
    alternateSymbols: ["MRF", "Rf", "/-", "ރ"],
    subunit: "Laari",
    subunitToUnit: 100,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 462,
    smallestDenomination: 1,
  ),
  "mwk": Currency(
    isoCode: "MWK",
    name: "Malawian Kwacha",
    symbol: "MK",
    alternateSymbols: [],
    subunit: "Tambala",
    subunitToUnit: 100,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 454,
    smallestDenomination: 1,
  ),
  "mxn": Currency(
    isoCode: "MXN",
    name: "Mexican Peso",
    symbol: "\$",
    disambiguateSymbol: "MEX\$",
    alternateSymbols: ["MEX\$"],
    subunit: "Centavo",
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 484,
    smallestDenomination: 5,
  ),
  "myr": Currency(
    isoCode: "MYR",
    name: "Malaysian Ringgit",
    symbol: "RM",
    alternateSymbols: [],
    subunit: "Sen",
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 458,
    smallestDenomination: 5,
  ),
  "mzn": Currency(
    isoCode: "MZN",
    name: "Mozambican Metical",
    symbol: "MTn",
    alternateSymbols: ["MZN"],
    subunit: "Centavo",
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ",",
    thousandsSeparator: ".",
    isoNumeric: 943,
    smallestDenomination: 1,
  ),
  "nad": Currency(
    isoCode: "NAD",
    name: "Namibian Dollar",
    symbol: "\$",
    disambiguateSymbol: "N\$",
    alternateSymbols: ["N\$"],
    subunit: "Cent",
    subunitToUnit: 100,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 516,
    smallestDenomination: 5,
  ),
  "ngn": Currency(
    isoCode: "NGN",
    name: "Nigerian Naira",
    symbol: "₦",
    alternateSymbols: [],
    subunit: "Kobo",
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 566,
    smallestDenomination: 50,
  ),
  "nio": Currency(
    isoCode: "NIO",
    name: "Nicaraguan Córdoba",
    symbol: "C\$",
    disambiguateSymbol: "NIO\$",
    alternateSymbols: [],
    subunit: "Centavo",
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 558,
    smallestDenomination: 5,
  ),
  "nok": Currency(
    isoCode: "NOK",
    name: "Norwegian Krone",
    symbol: "kr",
    disambiguateSymbol: "NOK",
    alternateSymbols: [",-"],
    subunit: "Øre",
    subunitToUnit: 100,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ",",
    thousandsSeparator: ".",
    isoNumeric: 578,
    smallestDenomination: 100,
  ),
  "npr": Currency(
    isoCode: "NPR",
    name: "Nepalese Rupee",
    symbol: "Rs.",
    disambiguateSymbol: "NPR",
    alternateSymbols: ["Rs", "रू", "₨"],
    subunit: "Paisa",
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 524,
    smallestDenomination: 1,
  ),
  "nzd": Currency(
    isoCode: "NZD",
    name: "New Zealand Dollar",
    symbol: "\$",
    disambiguateSymbol: "NZ\$",
    alternateSymbols: ["NZ\$"],
    subunit: "Cent",
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 554,
    smallestDenomination: 10,
  ),
  "omr": Currency(
    isoCode: "OMR",
    name: "Omani Rial",
    symbol: "ر.ع.",
    alternateSymbols: [],
    subunit: "Baisa",
    subunitToUnit: 1000,
    symbolFirst: true,
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 512,
    smallestDenomination: 5,
  ),
  "pab": Currency(
    isoCode: "PAB",
    name: "Panamanian Balboa",
    symbol: "B/.",
    alternateSymbols: [],
    subunit: "Centésimo",
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 590,
    smallestDenomination: 1,
  ),
  "pen": Currency(
    isoCode: "PEN",
    name: "Peruvian Sol",
    symbol: "S/",
    alternateSymbols: [],
    subunit: "Céntimo",
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 604,
    smallestDenomination: 1,
  ),
  "pgk": Currency(
    isoCode: "PGK",
    name: "Papua New Guinean Kina",
    symbol: "K",
    disambiguateSymbol: "PGK",
    alternateSymbols: [],
    subunit: "Toea",
    subunitToUnit: 100,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 598,
    smallestDenomination: 5,
  ),
  "php": Currency(
    isoCode: "PHP",
    name: "Philippine Peso",
    symbol: "₱",
    alternateSymbols: ["PHP", "PhP", "P"],
    subunit: "Centavo",
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 608,
    smallestDenomination: 1,
  ),
  "pkr": Currency(
    isoCode: "PKR",
    name: "Pakistani Rupee",
    symbol: "₨",
    disambiguateSymbol: "PKR",
    alternateSymbols: ["Rs"],
    subunit: "Paisa",
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 586,
    smallestDenomination: 100,
  ),
  "pln": Currency(
    isoCode: "PLN",
    name: "Polish Złoty",
    symbol: "zł",
    alternateSymbols: [],
    subunit: "Grosz",
    subunitToUnit: 100,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ",",
    thousandsSeparator: " ",
    isoNumeric: 985,
    smallestDenomination: 1,
  ),
  "pyg": Currency(
    isoCode: "PYG",
    name: "Paraguayan Guaraní",
    symbol: "₲",
    alternateSymbols: [],
    subunit: "Céntimo",
    subunitToUnit: 1,
    symbolFirst: true,
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 600,
    smallestDenomination: 5000,
  ),
  "qar": Currency(
    isoCode: "QAR",
    name: "Qatari Riyal",
    symbol: "ر.ق",
    alternateSymbols: ["QR"],
    subunit: "Dirham",
    subunitToUnit: 100,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 634,
    smallestDenomination: 1,
  ),
  "ron": Currency(
    isoCode: "RON",
    name: "Romanian Leu",
    symbol: "Lei",
    alternateSymbols: [],
    subunit: "Bani",
    subunitToUnit: 100,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ",",
    thousandsSeparator: ".",
    isoNumeric: 946,
    smallestDenomination: 1,
  ),
  "rsd": Currency(
    isoCode: "RSD",
    name: "Serbian Dinar",
    symbol: "РСД",
    alternateSymbols: ["RSD", "din", "дин"],
    subunit: "Para",
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 941,
    smallestDenomination: 100,
  ),
  "rub": Currency(
    isoCode: "RUB",
    name: "Russian Ruble",
    symbol: "₽",
    alternateSymbols: ["руб.", "р."],
    subunit: "Kopeck",
    subunitToUnit: 100,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ",",
    thousandsSeparator: ".",
    isoNumeric: 643,
    smallestDenomination: 1,
  ),
  "rwf": Currency(
    isoCode: "RWF",
    name: "Rwandan Franc",
    symbol: "FRw",
    alternateSymbols: ["RF", "R₣"],
    subunit: "Centime",
    subunitToUnit: 1,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 646,
    smallestDenomination: 100,
  ),
  "sar": Currency(
    isoCode: "SAR",
    name: "Saudi Riyal",
    symbol: "ر.س",
    alternateSymbols: ["SR", "﷼"],
    subunit: "Hallallah",
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 682,
    smallestDenomination: 5,
  ),
  "sbd": Currency(
    isoCode: "SBD",
    name: "Solomon Islands Dollar",
    symbol: "\$",
    disambiguateSymbol: "SI\$",
    alternateSymbols: ["SI\$"],
    subunit: "Cent",
    subunitToUnit: 100,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 090,
    smallestDenomination: 10,
  ),
  "scr": Currency(
    isoCode: "SCR",
    name: "Seychellois Rupee",
    symbol: "₨",
    disambiguateSymbol: "SRe",
    alternateSymbols: ["SRe", "SR"],
    subunit: "Cent",
    subunitToUnit: 100,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 690,
    smallestDenomination: 1,
  ),
  "sdg": Currency(
    isoCode: "SDG",
    name: "Sudanese Pound",
    symbol: "£",
    disambiguateSymbol: "SDG",
    alternateSymbols: [],
    subunit: "Piastre",
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 938,
    smallestDenomination: 1,
  ),
  "sek": Currency(
    isoCode: "SEK",
    name: "Swedish Krona",
    symbol: "kr",
    disambiguateSymbol: "SEK",
    alternateSymbols: [":-"],
    subunit: "Öre",
    subunitToUnit: 100,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ",",
    thousandsSeparator: " ",
    isoNumeric: 752,
    smallestDenomination: 100,
  ),
  "sgd": Currency(
    isoCode: "SGD",
    name: "Singapore Dollar",
    symbol: "\$",
    disambiguateSymbol: "S\$",
    alternateSymbols: ["S\$"],
    subunit: "Cent",
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 702,
    smallestDenomination: 1,
  ),
  "shp": Currency(
    isoCode: "SHP",
    name: "Saint Helenian Pound",
    symbol: "£",
    disambiguateSymbol: "SHP",
    alternateSymbols: [],
    subunit: "Penny",
    subunitToUnit: 100,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 654,
    smallestDenomination: 1,
  ),
  "skk": Currency(
    isoCode: "SKK",
    name: "Slovak Koruna",
    symbol: "Sk",
    alternateSymbols: [],
    subunit: "Halier",
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 703,
    smallestDenomination: 50,
  ),
  "sll": Currency(
    isoCode: "SLL",
    name: "Sierra Leonean Leone",
    symbol: "Le",
    alternateSymbols: [],
    subunit: "Cent",
    subunitToUnit: 100,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 694,
    smallestDenomination: 1000,
  ),
  "sos": Currency(
    isoCode: "SOS",
    name: "Somali Shilling",
    symbol: "Sh",
    alternateSymbols: ["Sh.So"],
    subunit: "Cent",
    subunitToUnit: 100,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 706,
    smallestDenomination: 1,
  ),
  "srd": Currency(
    isoCode: "SRD",
    name: "Surinamese Dollar",
    symbol: "\$",
    disambiguateSymbol: "SRD",
    alternateSymbols: [],
    subunit: "Cent",
    subunitToUnit: 100,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 968,
    smallestDenomination: 1,
  ),
  "ssp": Currency(
    isoCode: "SSP",
    name: "South Sudanese Pound",
    symbol: "£",
    disambiguateSymbol: "SSP",
    alternateSymbols: [],
    subunit: "piaster",
    subunitToUnit: 100,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 728,
    smallestDenomination: 5,
  ),
  "std": Currency(
    isoCode: "STD",
    name: "São Tomé and Príncipe Dobra",
    symbol: "Db",
    alternateSymbols: [],
    subunit: "Cêntimo",
    subunitToUnit: 100,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 678,
    smallestDenomination: 10000,
  ),
  "svc": Currency(
    isoCode: "SVC",
    name: "Salvadoran Colón",
    symbol: "₡",
    alternateSymbols: ["¢"],
    subunit: "Centavo",
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 222,
    smallestDenomination: 1,
  ),
  "syp": Currency(
    isoCode: "SYP",
    name: "Syrian Pound",
    symbol: "£S",
    alternateSymbols: ["£", "ل.س", "LS", "الليرة السورية"],
    subunit: "Piastre",
    subunitToUnit: 100,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 760,
    smallestDenomination: 100,
  ),
  "szl": Currency(
    isoCode: "SZL",
    name: "Swazi Lilangeni",
    symbol: "E",
    disambiguateSymbol: "SZL",
    subunit: "Cent",
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 748,
    smallestDenomination: 1,
  ),
  "thb": Currency(
    isoCode: "THB",
    name: "Thai Baht",
    symbol: "฿",
    alternateSymbols: [],
    subunit: "Satang",
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 764,
    smallestDenomination: 1,
  ),
  "tjs": Currency(
    isoCode: "TJS",
    name: "Tajikistani Somoni",
    symbol: "ЅМ",
    alternateSymbols: [],
    subunit: "Diram",
    subunitToUnit: 100,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 972,
    smallestDenomination: 1,
  ),
  "tmt": Currency(
    isoCode: "TMT",
    name: "Turkmenistani Manat",
    symbol: "T",
    alternateSymbols: [],
    subunit: "Tenge",
    subunitToUnit: 100,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 934,
    smallestDenomination: 1,
  ),
  "tnd": Currency(
    isoCode: "TND",
    name: "Tunisian Dinar",
    symbol: "د.ت",
    alternateSymbols: ["TD", "DT"],
    subunit: "Millime",
    subunitToUnit: 1000,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 788,
    smallestDenomination: 10,
  ),
  "top": Currency(
    isoCode: "TOP",
    name: "Tongan Paʻanga",
    symbol: "T\$",
    alternateSymbols: ["PT"],
    subunit: "Seniti",
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 776,
    smallestDenomination: 1,
  ),
  "try": Currency(
    isoCode: "TRY",
    name: "Turkish Lira",
    symbol: "₺",
    alternateSymbols: ["TL"],
    subunit: "kuruş",
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ",",
    thousandsSeparator: ".",
    isoNumeric: 949,
    smallestDenomination: 1,
  ),
  "ttd": Currency(
    isoCode: "TTD",
    name: "Trinidad and Tobago Dollar",
    symbol: "\$",
    disambiguateSymbol: "TT\$",
    alternateSymbols: ["TT\$"],
    subunit: "Cent",
    subunitToUnit: 100,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 780,
    smallestDenomination: 1,
  ),
  "twd": Currency(
    isoCode: "TWD",
    name: "New Taiwan Dollar",
    symbol: "\$",
    disambiguateSymbol: "NT\$",
    alternateSymbols: ["NT\$"],
    subunit: "Cent",
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 901,
    smallestDenomination: 50,
  ),
  "tzs": Currency(
    isoCode: "TZS",
    name: "Tanzanian Shilling",
    symbol: "Sh",
    alternateSymbols: [],
    subunit: "Cent",
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 834,
    smallestDenomination: 5000,
  ),
  "uah": Currency(
    isoCode: "UAH",
    name: "Ukrainian Hryvnia",
    symbol: "₴",
    alternateSymbols: [],
    subunit: "Kopiyka",
    subunitToUnit: 100,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 980,
    smallestDenomination: 1,
  ),
  "ugx": Currency(
    isoCode: "UGX",
    name: "Ugandan Shilling",
    symbol: "USh",
    alternateSymbols: [],
    subunit: "Cent",
    subunitToUnit: 1,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 800,
    smallestDenomination: 1000,
  ),
  "usd": Currency(
    isoCode: "USD",
    name: "United States Dollar",
    symbol: "\$",
    disambiguateSymbol: "US\$",
    alternateSymbols: ["US\$"],
    subunit: "Cent",
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 840,
    smallestDenomination: 1,
  ),
  "uyu": Currency(
    isoCode: "UYU",
    name: "Uruguayan Peso",
    symbol: "\$U",
    alternateSymbols: ["\$U"],
    subunit: "Centésimo",
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ",",
    thousandsSeparator: ".",
    isoNumeric: 858,
    smallestDenomination: 100,
  ),
  "uzs": Currency(
    isoCode: "UZS",
    name: "Uzbekistan Som",
    symbol: "so'm",
    alternateSymbols: ["so‘m", "сўм", "сум", "s", "с"],
    subunit: "Tiyin",
    subunitToUnit: 100,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 860,
    smallestDenomination: 100,
  ),
  "ves": Currency(
    isoCode: "VES",
    name: "Venezuelan Bolívar Soberano",
    symbol: "Bs",
    alternateSymbols: ["Bs.S"],
    subunit: "Céntimo",
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ",",
    thousandsSeparator: ".",
    isoNumeric: 928,
    smallestDenomination: 1,
  ),
  "vnd": Currency(
    isoCode: "VND",
    name: "Vietnamese Đồng",
    symbol: "₫",
    alternateSymbols: [],
    subunit: "Hào",
    subunitToUnit: 1,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ",",
    thousandsSeparator: ".",
    isoNumeric: 704,
    smallestDenomination: 100,
  ),
  "vuv": Currency(
    isoCode: "VUV",
    name: "Vanuatu Vatu",
    symbol: "Vt",
    alternateSymbols: [],
    subunit: null,
    subunitToUnit: 1,
    symbolFirst: true,
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 548,
    smallestDenomination: 1,
  ),
  "wst": Currency(
    isoCode: "WST",
    name: "Samoan Tala",
    symbol: "T",
    disambiguateSymbol: "WS\$",
    alternateSymbols: ["WS\$", "SAT", "ST"],
    subunit: "Sene",
    subunitToUnit: 100,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 882,
    smallestDenomination: 10,
  ),
  "xaf": Currency(
    isoCode: "XAF",
    name: "Central African Cfa Franc",
    symbol: "CFA",
    disambiguateSymbol: "FCFA",
    alternateSymbols: ["FCFA"],
    subunit: "Centime",
    subunitToUnit: 1,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 950,
    smallestDenomination: 100,
  ),
  "xag": Currency(
    isoCode: "XAG",
    name: "Silver (Troy Ounce)",
    symbol: "oz t",
    disambiguateSymbol: "XAG",
    alternateSymbols: [],
    subunit: "oz",
    subunitToUnit: 1,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 961,
  ),
  "xau": Currency(
    isoCode: "XAU",
    name: "Gold (Troy Ounce)",
    symbol: "oz t",
    disambiguateSymbol: "XAU",
    alternateSymbols: [],
    subunit: "oz",
    subunitToUnit: 1,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 959,
  ),
  "xba": Currency(
    isoCode: "XBA",
    name: "European Composite Unit",
    symbol: "",
    disambiguateSymbol: "XBA",
    alternateSymbols: [],
    subunit: "",
    subunitToUnit: 1,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 955,
  ),
  "xbb": Currency(
    isoCode: "XBB",
    name: "European Monetary Unit",
    symbol: "",
    disambiguateSymbol: "XBB",
    alternateSymbols: [],
    subunit: "",
    subunitToUnit: 1,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 956,
  ),
  "xbc": Currency(
    isoCode: "XBC",
    name: "European Unit of Account 9",
    symbol: "",
    disambiguateSymbol: "XBC",
    alternateSymbols: [],
    subunit: "",
    subunitToUnit: 1,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 957,
  ),
  "xbd": Currency(
    isoCode: "XBD",
    name: "European Unit of Account 17",
    symbol: "",
    disambiguateSymbol: "XBD",
    alternateSymbols: [],
    subunit: "",
    subunitToUnit: 1,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 958,
  ),
  "xcd": Currency(
    isoCode: "XCD",
    name: "East Caribbean Dollar",
    symbol: "\$",
    disambiguateSymbol: "EX\$",
    alternateSymbols: ["EC\$"],
    subunit: "Cent",
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 951,
    smallestDenomination: 1,
  ),
  "xdr": Currency(
    isoCode: "XDR",
    name: "Special Drawing Rights",
    symbol: "SDR",
    alternateSymbols: ["XDR"],
    subunit: "",
    subunitToUnit: 1,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 968,
  ),
  "xof": Currency(
    isoCode: "XOF",
    name: "West African Cfa Franc",
    symbol: "Fr",
    disambiguateSymbol: "CFA",
    alternateSymbols: ["CFA"],
    subunit: "Centime",
    subunitToUnit: 1,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 952,
    smallestDenomination: 100,
  ),
  "xpd": Currency(
    isoCode: "XPD",
    name: "Palladium",
    symbol: "oz t",
    disambiguateSymbol: "XPD",
    alternateSymbols: [],
    subunit: "oz",
    subunitToUnit: 1,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 964,
  ),
  "xpf": Currency(
    isoCode: "XPF",
    name: "Cfp Franc",
    symbol: "Fr",
    alternateSymbols: ["F"],
    subunit: "Centime",
    subunitToUnit: 1,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 953,
    smallestDenomination: 100,
  ),
  "xpt": Currency(
    isoCode: "XPT",
    name: "Platinum",
    symbol: "oz t",
    alternateSymbols: [],
    subunit: "",
    subunitToUnit: 1,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 962,
  ),
  "yer": Currency(
    isoCode: "YER",
    name: "Yemeni Rial",
    symbol: "﷼",
    alternateSymbols: [],
    subunit: "Fils",
    subunitToUnit: 100,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 886,
    smallestDenomination: 100,
  ),
  "zar": Currency(
    isoCode: "ZAR",
    name: "South African Rand",
    symbol: "R",
    alternateSymbols: [],
    subunit: "Cent",
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 710,
    smallestDenomination: 10,
  ),
  "zmk": Currency(
    isoCode: "ZMK",
    name: "Zambian Kwacha",
    symbol: "ZK",
    disambiguateSymbol: "ZMK",
    alternateSymbols: [],
    subunit: "Ngwee",
    subunitToUnit: 100,
    symbolFirst: false,
    format: "%n %u",
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 894,
    smallestDenomination: 5,
  ),
  "zmw": Currency(
    isoCode: "ZMW",
    name: "Zambian Kwacha",
    symbol: "K",
    disambiguateSymbol: "ZMW",
    alternateSymbols: [],
    subunit: "Ngwee",
    subunitToUnit: 100,
    symbolFirst: true,
    decimalMark: ".",
    thousandsSeparator: ",",
    isoNumeric: 967,
    smallestDenomination: 5,
  ),
};
